@@ -13,7 +13,7 @@ require HTML::DOM::Element;
 require HTML::DOM::NodeList::Magic;
 #require HTML::DOM::Collection::Elements;
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = qw'HTML::DOM::Element HTML::Form';
 
 use overload fallback => 1,
@@ -74,6 +74,17 @@ sub reset { #$_->_reset for shift->elements
 	shift->trigger_event('reset');
 }
 
+sub trigger_event {
+	my ($a,$evnt) = (shift,shift);
+	my $name = ref $evnt && eval{$evnt->type} || $evnt;
+	$a->SUPER::trigger_event(
+		$evnt,
+		$name =~ /^(?:rese|submi)t\z/i
+		 && $a->ownerDocument->default_event_handler_for($name)
+		 || @_
+	);
+}
+
 # ------ HTML::Form compatibility methods ------ #
 
 sub AUTOLOAD { # so we don't have to load it unnecessarily
@@ -299,7 +310,7 @@ package HTML::DOM::NodeList::Radio; # solely for HTML::Form compatibility
 use Carp 'croak';
 require HTML::DOM::NodeList;
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = qw'HTML::DOM::NodeList HTML::Form::Input';
 
 sub type { 'radio' }
@@ -382,7 +393,7 @@ use warnings;
 
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 require HTML::DOM::Collection;
 our @ISA = 'HTML::DOM::Collection';
@@ -553,7 +564,7 @@ L<HTML::Form>
 # ------- HTMLSelectElement interface ---------- #
 
 package HTML::DOM::Element::Select;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = 'HTML::DOM::Element';
 
 use overload fallback=>1, '@{}' => sub { shift->options };
@@ -634,7 +645,7 @@ package HTML::DOM::Collection::Options;
 use strict;
 use warnings;
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 use Carp 'croak';
 use constant::lexical sel => 5; # must not conflict with super
@@ -725,7 +736,7 @@ sub form_name_value
 # ------- HTMLOptGroupElement interface ---------- #
 
 package HTML::DOM::Element::OptGroup;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = 'HTML::DOM::Element';
 
 sub label  { shift->attr( label => @_) }
@@ -735,7 +746,7 @@ sub label  { shift->attr( label => @_) }
 # ------- HTMLOptionElement interface ---------- #
 
 package HTML::DOM::Element::Option;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = qw'HTML::DOM::Element HTML::Form::Input';
 
 use Carp 'croak';
@@ -859,7 +870,7 @@ sub form_name_value
 # ------- HTMLInputElement interface ---------- #
 
 package HTML::DOM::Element::Input;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -891,7 +902,7 @@ sub readOnly  { shift->attr( readonly => @_) }
 sub src       { shift->attr( src => @_) }
 *tabIndex = \&HTML::DOM::Element::Select::tabIndex;
 sub type      {
-	my $ret = shift->attr('type');
+	my $ret = shift->attr('type', @_);
 	return defined $ret ? lc $ret : 'text'
 }
 sub useMap    { shift->attr( usemap => @_) }
@@ -920,7 +931,7 @@ sub value        {
 
 # ~~~ shouldn't I make sure that modifying the value attribute 
 #     (=defaultValue) leaves the value alone, even if the value has not
-#     yet been accessed?
+#     yet been accessed? (The same goes for checked and $option->selected)
 	if(!defined $self->{_HTML_DOM_value}) {
 		$ret = $self->defaultValue
 	}
@@ -944,6 +955,19 @@ sub click { for(shift){
 	return;
 }}
 
+sub trigger_event {
+	my ($a,$evnt) = (shift,shift);
+	my $input_type = $a->type;
+	$a->SUPER::trigger_event(
+		$evnt,
+		(ref $evnt && eval{$evnt->type} || $evnt) =~ /^click\z/i
+		 && $input_type =~ /^(submi|rese)t\z/
+		 && $a->ownerDocument->default_event_handler_for(
+			"$input_type\_button")
+		 || @_
+	);
+}
+
 sub possible_values {
 	$_[0]->type eq 'checkbox' ? wantarray ? (undef, shift->value) : 2
 	: ()
@@ -1047,7 +1071,7 @@ sub content {
 # ------- HTMLTextAreaElement interface ---------- #
 
 package HTML::DOM::Element::TextArea;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = qw'HTML::DOM::Element HTML::Form::Input';
 
 sub defaultValue { # same as HTML::DOM::Element::Title::text
@@ -1102,7 +1126,7 @@ sub form_name_value
 # ------- HTMLButtonElement interface ---------- #
 
 package HTML::DOM::Element::Button;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1117,7 +1141,7 @@ sub value      { shift->attr( value       => @_) }
 # ------- HTMLLabelElement interface ---------- #
 
 package HTML::DOM::Element::Label;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1127,7 +1151,7 @@ sub htmlFor { shift->attr( for       => @_) }
 # ------- HTMLFieldSetElement interface ---------- #
 
 package HTML::DOM::Element::FieldSet;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1135,7 +1159,7 @@ our @ISA = qw'HTML::DOM::Element';
 # ------- HTMLLegendElement interface ---------- #
 
 package HTML::DOM::Element::Legend;
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
